@@ -115,8 +115,8 @@ class PRTGHTTPApi(object):
         if self.probe_config["disable_ssl_verification"]:
             verify_ssl = False
         async with httpx.AsyncClient(verify=verify_ssl) as client:
-            request = client.build_request(method="POST", url=api_url, data=post_data, params=url_params)
-            response = await client.send(request=request, timeout=10)
+            request = client.build_request(method="POST", url=api_url, data=post_data, params=url_params, timeout=10)
+            response = await client.send(request=request)
             if response.status_code in [400, 429, 500, 502, 503, 504]:
                 raise httpx.HTTPStatusError(message="Request failed.", request=request, response=response)
             return response
