@@ -50,7 +50,7 @@ class Sensor(SensorBase):
             name="ip",
             caption="IP Address",
             required="1",
-            help="Enter a DNS name to resolve.",
+            help="Enter am IP Address to resolve.",
         )
         dns_re_def.add_group(dns_re_def_group_dns_spec)
         return dns_re_def.data
