@@ -46,12 +46,9 @@ class Sensor(SensorBase):
 
             async with httpx.AsyncClient() as client:
                 request = client.build_request(
-                    method=request_type,
-                    url=url,
-                    headers=headers,
-                    data=post_data,
+                    method=request_type, url=url, headers=headers, data=post_data, timeout=int(task_data["timeout"])
                 )
-                response = await client.send(request=request, timeout=int(task_data["timeout"]))
+                response = await client.send(request=request)
 
             ext_ip_data.add_channel(
                 name="Response Time",
