@@ -143,6 +143,13 @@ class Sensor(SensorBase):
             ping_data.error_code = 1
             ping_data.message = "The pyprobe must run as root/administrator to use ICMP Ping"
             logging.exception("ICMP Ping uses RAW sockets. You must be root to use them.")
+        except OSError:
+            ping_data.error = "Exception"
+            ping_data.error_code = 1
+            ping_data.message = "Target device/port probably not available."
+            logging.exception(
+                "Something on the network level went wrong. " "Target host not reachable on selected port."
+            )
         await q.put(ping_data.data)
         q.task_done()
 
